DataLoaderConfig

Enum DataLoaderConfig 

pub enum DataLoaderConfig {
    Csv(CsvConfig),
    Parquet(ParquetConfig),
}
An enum representing the configuration for a specific data loader.

This allows the CDL pipeline to be configured for different data sources like CSV or Parquet files.

Variants