pub trait DataCleaner<T> {
// Required method
fn process(
&self,
tensor: CausalTensor<T>,
) -> Result<CausalTensor<Option<T>>, DataCleaningError>;
}Required Methods
Sourcefn process(
&self,
tensor: CausalTensor<T>,
) -> Result<CausalTensor<Option<T>>, DataCleaningError>
fn process( &self, tensor: CausalTensor<T>, ) -> Result<CausalTensor<Option<T>>, DataCleaningError>
Cleans the input tensor according to the provided configuration.
Arguments
tensor- The inputCausalTensor<T>to be processed.
Returns
A Result containing a new, processed CausalTensor<Option<T>> on success.
Errors
Returns a PreprocessError if the processing fails, for example due to an
invalid configuration or an issue with the data itself.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".